summaryrefslogtreecommitdiff
path: root/gpu/gl/GrGLProgram.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'gpu/gl/GrGLProgram.cpp')
-rw-r--r--gpu/gl/GrGLProgram.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/gpu/gl/GrGLProgram.cpp b/gpu/gl/GrGLProgram.cpp
index 6e9878a9..9b997c85 100644
--- a/gpu/gl/GrGLProgram.cpp
+++ b/gpu/gl/GrGLProgram.cpp
@@ -229,10 +229,11 @@ void GrGLProgram::setData(GrDrawState::BlendOptFlags blendOpts,
fCoverageEffects->setData(fGpu, fUniformManager, coverageStages);
// TexGen state applies to the the fixed function vertex shader. For custom shaders, it's
// ignored, so we don't need to change the texgen settings in that case.
if (!fHasVertexShader) {
- fGpu->flushTexGenSettings(fNumTexCoordSets);
+ fGpu->flushPathTexGenSettings(fNumTexCoordSets);
}
}
@@ -229,10 +229,11 @@ void GrGLProgram::setData(GrDrawState::BlendOptFlags blendOpts,
fCoverageEffects->setData(fGpu, fUniformManager, coverageStages);
- // TexGen state applies to the the fixed function vertex shader. For custom shaders, it's
- // ignored, so we don't need to change the texgen settings in that case.
+ // PathTexGen state applies to the the fixed function vertex shader. For
+ // custom shaders, it's ignored, so we don't need to change the texgen
+ // settings in that case.
if (!fHasVertexShader) {